# Description

Ce dépôt contient l'ensemble des procédures, scripts et fichiers de configuration nécessaires pour reproduire ce travail de thèse sur la traduction littéraire automatique adaptée au style individuel d'un traducteur ou d'une traductrice, à l'exception des corpus d'entraînement utilisés et des modèles de traductions obtenus, qui peuvent être téléchargés ailleurs ou sont protégés par le droit d'auteur. Le travail peut être consulté à l'adresse suivante&nbsp;: https://hdl.handle.net/2268/312631.

Outre la reproductibilité, ce dépôt vise à favoriser la prise en main d'outils tels qu'*OpenNMT* pour les personnes qui seraient peu familiarisées avec cet outil, mais aussi à montrer que la mise au point de systèmes individualisés diffère peu d'une simple adaptation au domaine, voire de l'entraînement classique d'un système de TA. Pour des informations plus détaillées sur les procédures décrites ici, voir le tutoriel proposé ici&nbsp;: https://gitlab.uliege.be/dhansen/tutorielmt.

# Marche à suivre

### Installation

Installer la liste des modules requis pour le traitement des données ([SentencePiece](https://github.com/google/sentencepiece)), l'entraînement ([OpenNMT](https://github.com/OpenNMT/OpenNMT-py)) et l'évaluation ([sacreBLEU](https://github.com/mjpost/sacrebleu), [COMET](https://github.com/Unbabel/COMET), [LexicalRichness](https://github.com/LSYS/LexicalRichness), [ASTrED](https://github.com/BramVanroy/astred)), ainsi que leurs dépendances&nbsp;:

    pip install -r requirements.txt

### Corpus

Si le système devrait au moins être affiné sur des données spécialisées de qualité, d'autres corpus peuvent néanmoins être utilisés pour mettre un point un système générique (à des fins de comparaison ou d'affinage). De nombreux corpus peuvent être récupérés pour ce faire depuis le dépôt [OPUS](https://opus.nlpl.eu/). Par exemple&nbsp;:

    wget https://object.pouta.csc.fi/OPUS-Books/v1/moses/en-fr.txt.zip -O ./data/books/books.zip
    unzip books.zip Books.en-fr.{en,fr}
    mv Books.en-fr.en books.en ; mv Books.en-fr.fr books.fr

Pour cet exemple, les corpus suivants issus du même dépôt ont été utilisés&nbsp;:
- Books ([v1](https://opus.nlpl.eu/Books/corpus/version/Books))
- Europarl ([v8](https://opus.nlpl.eu/Europarl/corpus/version/Europarl))
- GlobalVoices ([2018Q4](https://opus.nlpl.eu/GlobalVoices/corpus/version/GlobalVoices))
- News-Commentary ([v16](https://opus.nlpl.eu/News-Commentary/corpus/version/News-Commentary))
- TED2020 ([v1](https://opus.nlpl.eu/TED2020/corpus/version/TED2020))

### Pré-traitement

Tokenisation des corpus, création d'un modèle de segmentation en sous-mots et récupération du vocabulaire à utiliser à partir de fichiers `.en` et `.fr` répartis dans des dossiers isolés à l'intérieur de `./data`&nbsp;:

    bash preprocess.sh

Cette étape inclut la segmentation en sous-mot du fichier de test qui servira pour l'évaluation. Pour ce faire, il est impératif de prévoir une suite de test différente des corpus d'entraînement (ici, `tra.en` et `tra.fr`), ainsi qu'un corpus de validation qui servira pour l'entraînement (ici, `val.en` et `val.fr`).

### Entraînement

Entraînement et affinage de modèles génériques (LSTM et Transformer) à partir des configurations prévues dans le dossier `./configs`&nbsp;:

    bash train_lstm.sh
    bash train_transformer.sh

Cette étape inclut la production d'une traduction automatique pour chaque modèle résultant ainsi qu'une évaluation automatique simple qui permettra de suivre l'évolution de l'entraînement.

### Évaluation

Pour d'autres évaluations automatiques&nbsp;:

    bash evaluate.sh

# Citation

    @phdthesis{hansen:2024:thesis,
        title   = {Évaluation experte d'un prototype d'aide à la traduction créative : la traduction littéraire automatique individualisée au regard de ses enjeux traductologiques, éthiques et sociétaux},
        author  = {Hansen, Damien},
        year    = {2024},
        type    = {PhD thesis},
        school  = {University of Liège -- Grenoble Alpes University},
        url     = {https://hdl.handle.net/2268/312631}
    }