#!/bin/sh

# Directories
#############

export DIR=septimus
export OUT=lstm
mkdir -p ./output/${OUT}/{models,translations,logs,tensor}

# Training
##########

onmt_train --config ./configs/lstm_train.yaml 2>&1 | tee -a ./output/${OUT}/logs/train.log
onmt_train --config ./configs/lstm_tuned.yaml 2>&1 | tee -a ./output/${OUT}/logs/tuned.log
onmt_train --config ./configs/lstm_magyk.yaml 2>&1 | tee -a ./output/${OUT}/logs/magyk.log
onmt_train --config ./configs/lstm_varia.yaml 2>&1 | tee -a ./output/${OUT}/logs/varia.log
onmt_train --config ./configs/lstm_small.yaml 2>&1 | tee -a ./output/${OUT}/logs/small.log

echo "Training done!"

# Translation
#############

for checkpoint in ./output/${OUT}/models/*.pt; do
	filename=$(basename $checkpoint .pt)
	echo "# Translating checkpoint" ${filename}
	onmt_translate \
		--verbose \
		--model $checkpoint \
		--src ./data/${DIR}/tra_sub.en \
		--output ./output/${OUT}/translations/${filename}_sub.txt
done

for file in ./output/${OUT}/translations/*_sub.txt; do
    filename=$(basename $file _sub.txt)
    spm_decode \
        --model=./subword/septimus_fr.model \
        --input_format=piece \
        < ./output/${OUT}/translations/${filename%.*}_sub.txt \
        > ./output/${OUT}/translations/${filename%.*}_tok.txt
done

for file in ./output/${OUT}/translations/*_tok.txt; do
    filename=$(basename $file _tok.txt)
	perl detokenizer.perl \
		-l fr \
		-lc \
		< ./output/${OUT}/translations/${filename%.*}_tok.txt \
		> ./output/${OUT}/translations/${filename%.*}.txt
done

rm ./output/${OUT}/translations/*sub.txt
rm ./output/${OUT}/translations/*tok.txt

echo "Translation done!"

# Evaluation
############

sacrebleu ./data/${DIR}/tra.fr \
	--input ./output/${OUT}/translations/*.txt \
	--language-pair en-fr \
	--metrics bleu chrf ter \
	--chrf-word-order 2 \
	--tokenize 13a \
	--width 2 \
	--format text \
	>> ./output/${OUT}/BLEU.txt

echo "Evaluation done!"
